summaryrefslogtreecommitdiff
path: root/nuttx/net/tcp/tcp_send.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/net/tcp/tcp_send.c')
-rw-r--r--nuttx/net/tcp/tcp_send.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/nuttx/net/tcp/tcp_send.c b/nuttx/net/tcp/tcp_send.c
index eb672723c..46e24bcdf 100644
--- a/nuttx/net/tcp/tcp_send.c
+++ b/nuttx/net/tcp/tcp_send.c
@@ -190,9 +190,9 @@ static void tcp_sendcommon(FAR struct net_driver_s *dev,
net_ipaddr_hdrcopy(pbuf->srcipaddr, &dev->d_ipaddr);
net_ipaddr_hdrcopy(pbuf->destipaddr, &conn->ripaddr);
- if (conn->tcpstateflags & UIP_STOPPED)
+ if (conn->tcpstateflags & TCP_STOPPED)
{
/* If the connection has issued UIP_STOPPED, we advertise a zero
* window so that the remote host will stop sending data.
*/
@@ -190,9 +190,9 @@ static void tcp_sendcommon(FAR struct net_driver_s *dev,
{
- /* If the connection has issued UIP_STOPPED, we advertise a zero
+ /* If the connection has issued TCP_STOPPED, we advertise a zero
* window so that the remote host will stop sending data.
*/